#include <windows.h>
#include "resource.h"
#include "LELanio.h"



#define CONNECT_LANIO_TIMEOUT_TIME 1000     /* millisecond  */
#define SEARCH_LANIO_TIMEOUT_TIME  100      /* millisecond  */



/*--------------------------------------------------------------------------*/
/* Global variable                                                          */
/*--------------------------------------------------------------------------*/
HINSTANCE g_hInstance;		/* Save hInstance                               */
hLANIO g_hLanio = -1;		/* Handle of connection with LANIO uint         */

typedef struct{
	int DIenable;
	int Logic;
}emailalert;				/* Factory default  e-mail alert */

typedef struct {
	int DisconnectTime;
	int PeriodicallyTransmissionTime;
	int DetectionTime;
	emailalert DI[5];
}factorydefault;			/* Factory default */

factorydefault la5ppdefault;

/*--------------------------------------------------------------------------*/
/* Display error message box from LANIO library                             */
/*--------------------------------------------------------------------------*/
void DisplayLanioErrorMessage( HWND hwnd, int ErrorCode )
{
    char msgbuf[32];

    wsprintf( msgbuf, "Error code : %d", ErrorCode );
    MessageBox( hwnd, msgbuf, "LANIO Error", MB_ICONEXCLAMATION | MB_OK );
}



/*--------------------------------------------------------------------------*/
/* Enable/Disable Controls for Offline state                                */
/*--------------------------------------------------------------------------*/
void EnableOfflineControls( HWND hwnd, BOOL fEnable )
{
    EnableWindow( GetDlgItem( hwnd, IDC_IPADDRESS ), fEnable );				/* "IP Address" edit box    */
    EnableWindow( GetDlgItem( hwnd, IDC_CONNECTBYIPADDRESS ), fEnable );    /* first "Connect" button 	*/

    if( fEnable )															/* Change default button and set focus	*/
    {
        SendMessage( hwnd, DM_SETDEFID, IDC_CONNECTBYIPADDRESS, 0 );
        SendMessage( hwnd, WM_NEXTDLGCTL,
                    (WPARAM)GetDlgItem( hwnd, IDC_IPADDRESS ), MAKELPARAM( TRUE, 0 ) );
    }
}



/*--------------------------------------------------------------------------*/
/* Enable/Disable Controls for Online state                                 */
/*--------------------------------------------------------------------------*/
void EnableOnlineControls( HWND hwnd, BOOL fEnable )
{
    EnableWindow( GetDlgItem( hwnd, IDC_WRITEDISCONNECTTIME ), fEnable );				/* Disconnect Time "Write" button       */
    EnableWindow( GetDlgItem( hwnd, IDC_READDISCONNECTTIME ), fEnable );				/* Disconnect Time "Read" button        */
 
    EnableWindow( GetDlgItem( hwnd, IDC_WRITEPERIODICALLYTRANSMISSIONTIME ), fEnable );	/* Periodically Transmission Time "Write" button       */
    EnableWindow( GetDlgItem( hwnd, IDC_READPERIODICALLYTRANSMISSIONTIME ), fEnable );  /* Periodically Transmission Time "Read" button        */
 
	EnableWindow( GetDlgItem( hwnd, IDC_WRITEDIDETECTTIME ), fEnable );					/* DI Detect Time "Write" button       */
    EnableWindow( GetDlgItem( hwnd, IDC_READDIDETECTTIME ), fEnable );					/* DI Detect Time "Read" button        */

	EnableWindow( GetDlgItem( hwnd, IDC_WRITEDIEMAILALERT ), fEnable );					/* DI e-mail alert "Write" button       */
    EnableWindow( GetDlgItem( hwnd, IDC_READDIEMAILALERT ), fEnable );					/* DI e-mail alert "Read" button        */

    EnableWindow( GetDlgItem( hwnd, IDC_DISCONNECT ), fEnable );						/* "Disconnect" button      */

    if( fEnable )																		/* Change default button and set focus	*/
    {
        SendMessage( hwnd, DM_SETDEFID, IDC_DISCONNECT, 0 );
        SendMessage( hwnd, WM_NEXTDLGCTL,
                    (WPARAM)GetDlgItem( hwnd, IDC_DISCONNECT ), MAKELPARAM( TRUE, 0 ) );
    }
}



/*--------------------------------------------------------------------------*/
/* Connect with LANIO unit by IP Address                                    */
/*--------------------------------------------------------------------------*/
void ConnectLanioByIpAddress( HWND hwnd )
{
    char ipaddress[256];

    EnableOfflineControls( hwnd, FALSE );
													/* Get target IP address from edit box  */
    GetDlgItemText( hwnd, IDC_IPADDRESS, ipaddress, sizeof( ipaddress ) );

													/* #### Direct connect                  */
    g_hLanio = LELanioConnectDirect( ipaddress, CONNECT_LANIO_TIMEOUT_TIME );
    if( g_hLanio == -1 )                            /* If error occurred, ...    */
    {
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        EnableOfflineControls( hwnd, TRUE );
        return;
    }

    EnableOnlineControls( hwnd, TRUE );

}


/*--------------------------------------------------------------------------*/
/* Disconnect with LANIO unit                                               */
/*--------------------------------------------------------------------------*/
void DisconnectLanio( HWND hwnd )
{
    int result;

    EnableOnlineControls( hwnd, FALSE );

    result = LELanioClose( g_hLanio );				/* #### Close connection	*/

    g_hLanio = -1;

    if( result == 0 )                               /* If error occurred, ...	*/
    {
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
    }

    EnableOfflineControls( hwnd, TRUE );
}



/*--------------------------------------------------------------------------*/
/* Disconnect Time data set to LANIO unit                                   */
/*--------------------------------------------------------------------------*/
void WriteDisconnectTime( HWND hwnd )
{
    int num;
													/* Get Disconnect Time number from combo box */
	num = SendMessage( GetDlgItem(hwnd, IDC_DISCONNECTTIME), CB_GETCURSEL, 0,0 );

	if( MessageBox( hwnd, "Periodically Transmission Time is also changed.", "LANIO LA-5P-P", MB_ICONEXCLAMATION | MB_OKCANCEL ) != IDOK )
	{
		return;
	}
													/* #### Set to LANIO unit    */
    if( LELanioSetDisconnectionTime( g_hLanio, num ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
    }
}



/*--------------------------------------------------------------------------*/
/* Disconnect Time data get from LANIO unit                                 */
/*--------------------------------------------------------------------------*/
void ReadDisconnectTime( HWND hwnd )
{
    int val;
													/* #### Get from LANIO unit   */
    if( LELanioGetDisconnectionTime( g_hLanio, &val ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        return;
    }
													/* String of the combo box select from value */
	SendDlgItemMessage( hwnd, IDC_DISCONNECTTIME, CB_SETCURSEL, val, 0 );

}



/*--------------------------------------------------------------------------*/
/* Periodically Transmission Time data set to LANIO unit                    */
/*--------------------------------------------------------------------------*/
void WritePeriodicallyTransmissionTime( HWND hwnd )
{
    int num;
													/* Get Periodically Transmission Time number from combo box */
	num = SendMessage( GetDlgItem(hwnd, IDC_PERIODICALLYTRANSMISSIONTIME), CB_GETCURSEL, 0,0 );

    if( MessageBox( hwnd, "Disconnect Time is also changed.", "LANIO LA-5P-P", MB_ICONEXCLAMATION | MB_OKCANCEL ) != IDOK )
	{
		return;
	}
													/* #### Set to LANIO unit    */
    if( LELanioSetNoticeTime( g_hLanio, num ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
    }
}


/*--------------------------------------------------------------------------*/
/* Periodically Transmission Time data get from LANIO unit                  */
/*--------------------------------------------------------------------------*/
void ReadPeriodicallyTransmissionTime( HWND hwnd )
{
    int val;
													/* #### Get from LANIO unit   */
    if( LELanioGetNoticeTime( g_hLanio, &val ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        return;
    }
													/* String of the combo box select from value */
	SendDlgItemMessage( hwnd, IDC_PERIODICALLYTRANSMISSIONTIME, CB_SETCURSEL, val, 0 );

}


/*--------------------------------------------------------------------------*/
/* DI Detection Time data set to LANIO unit                                 */
/*--------------------------------------------------------------------------*/
void WriteDIDetectionTime( HWND hwnd )
{
    int num;
													/* Get DI Detection Time number from combo box */
	num = SendMessage( GetDlgItem(hwnd, IDC_DIDETECTTIME), CB_GETCURSEL, 0,0 );

													/* #### Set to LANIO unit    */
    if( LELanioSetDiDetectTime( g_hLanio, num ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
    }
}


/*--------------------------------------------------------------------------*/
/* DI Detection Time data get from LANIO unit                               */
/*--------------------------------------------------------------------------*/
void ReadDIDetectionTime( HWND hwnd )
{
    int val;
													/* #### Get from LANIO unit   */
    if( LELanioGetDiDetectTime( g_hLanio, &val ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        return;
    }
													/* String of the combo box select from value */
	SendDlgItemMessage( hwnd, IDC_DIDETECTTIME, CB_SETCURSEL, val, 0 );
}

/*--------------------------------------------------------------------------*/
/* DI e-mail alert data set to LANIO unit									*/
/*--------------------------------------------------------------------------*/
void WriteDIeMailAlert( HWND hwnd )
{
    int enablenum=0;
    int logicnum=0;
													/* Get DI e-mail alert enable number from each DI check box   */
		enablenum = enablenum | (IsDlgButtonChecked( hwnd, IDC_CHECKDI1 ));		//bit0
		enablenum = enablenum | (IsDlgButtonChecked( hwnd, IDC_CHECKDI2 ) <<1);	//bit1
		enablenum = enablenum | (IsDlgButtonChecked( hwnd, IDC_CHECKDI3 ) <<2);	//bit2
		enablenum = enablenum | (IsDlgButtonChecked( hwnd, IDC_CHECKDI4 ) <<3);	//bit3
		enablenum = enablenum | (IsDlgButtonChecked( hwnd, IDC_CHECKDI5 ) <<4);	//bit4
													/* Get DI e-mail alert logic number from each DI combo box */
		logicnum = logicnum | (SendMessage( GetDlgItem(hwnd, IDC_DI1EMAILALERT), CB_GETCURSEL, 0,0 ));		//bit0
		logicnum = logicnum | (SendMessage( GetDlgItem(hwnd, IDC_DI2EMAILALERT), CB_GETCURSEL, 0,0 )<<1);	//bit1
		logicnum = logicnum | (SendMessage( GetDlgItem(hwnd, IDC_DI3EMAILALERT), CB_GETCURSEL, 0,0 )<<2);	//bit2
		logicnum = logicnum | (SendMessage( GetDlgItem(hwnd, IDC_DI4EMAILALERT), CB_GETCURSEL, 0,0 )<<3);	//bit3
		logicnum = logicnum | (SendMessage( GetDlgItem(hwnd, IDC_DI5EMAILALERT), CB_GETCURSEL, 0,0 )<<4);	//bit4


													/* #### Set to LANIO unit    */
	if( LELanioSetDiMailEnable( g_hLanio, enablenum ) == 0 )
	{                                               /* If error occurred, ...	*/
		DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
		return;
	}
													/* #### Set to LANIO unit    */
	if( LELanioSetDiMailLogic( g_hLanio, logicnum ) == 0 )
	{                                               /* If error occurred, ...	*/
		DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
		return;
	}
	
}


/*--------------------------------------------------------------------------*/
/* DI e-mail alert data get from LANIO unit									*/
/*--------------------------------------------------------------------------*/
void ReadDIeMailAlert( HWND hwnd )
{
	int enableval;
    int logicval;
													/* #### Get from LANIO unit   */
    if( LELanioGetDiMailEnable( g_hLanio, &enableval ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        return;
    }
													/* #### Get from LANIO unit   */
	if( LELanioGetDiMailLogic( g_hLanio, &logicval ) == 0 )
    {                                               /* If error occurred, ...	*/
        DisplayLanioErrorMessage( hwnd, LELanioGetLastError() );
        return;
    }
													/* Choice each DI check box state from value */
	CheckDlgButton(hwnd,IDC_CHECKDI1, enableval & 0x01);		//bit0
	CheckDlgButton(hwnd,IDC_CHECKDI2, (enableval>>1) & 0x01);	//bit1
	CheckDlgButton(hwnd,IDC_CHECKDI3, (enableval>>2) & 0x01);	//bit2
	CheckDlgButton(hwnd,IDC_CHECKDI4, (enableval>>3) & 0x01);	//bit3
	CheckDlgButton(hwnd,IDC_CHECKDI5, (enableval>>4) & 0x01);	//bit4

													/* String of each DI combo box select from value */
	SendDlgItemMessage( hwnd, IDC_DI1EMAILALERT, CB_SETCURSEL, logicval & 0x01, 0 );		//bit0
	SendDlgItemMessage( hwnd, IDC_DI2EMAILALERT, CB_SETCURSEL, (logicval>>1) & 0x01, 0 );	//bit1
	SendDlgItemMessage( hwnd, IDC_DI3EMAILALERT, CB_SETCURSEL, (logicval>>2) & 0x01, 0 );	//bit2
	SendDlgItemMessage( hwnd, IDC_DI4EMAILALERT, CB_SETCURSEL, (logicval>>3) & 0x01, 0 );	//bit3
	SendDlgItemMessage( hwnd, IDC_DI5EMAILALERT, CB_SETCURSEL, (logicval>>4) & 0x01, 0 );	//bit4

}


/*--------------------------------------------------------------------------*/
/* Process of WM_INITDIALOG message (Initialize dialog box)                 */
/*--------------------------------------------------------------------------*/
BOOL WmInitDialogMain( HWND hwnd )
{
    HICON hIcon;
	int i;
	
	la5ppdefault.DisconnectTime =15;
	la5ppdefault.PeriodicallyTransmissionTime =0;
	la5ppdefault.DetectionTime =10;
	la5ppdefault.DI[0].DIenable =1;
	la5ppdefault.DI[0].Logic=1;
    la5ppdefault.DI[1].DIenable =1;
	la5ppdefault.DI[1].Logic=1;
	la5ppdefault.DI[2].DIenable =1;
	la5ppdefault.DI[2].Logic=1;
	la5ppdefault.DI[3].DIenable =1;
	la5ppdefault.DI[3].Logic=1;
	la5ppdefault.DI[4].DIenable =1;
	la5ppdefault.DI[4].Logic=1;

	hIcon = (HICON)LoadImage( g_hInstance,
    						MAKEINTRESOURCE( IDI_MAIN ), IMAGE_ICON, 16, 16, 0 );
    SendMessage( hwnd, WM_SETICON, ICON_SMALL, (LPARAM)hIcon );
    hIcon = (HICON)LoadImage( g_hInstance,
    						MAKEINTRESOURCE( IDI_MAIN ), IMAGE_ICON, 32, 32, 0 );
    SendMessage( hwnd, WM_SETICON, ICON_BIG, (LPARAM)hIcon );

                                                        /* Initialize controls  */
    const char *Disconnecttime[16]={"0ms",	//0
									"300ms",//1
									"500ms",//2
									"1sec",	//3
									"3sec",	//4
									"5sec",	//5
									"10sec",//6	
									"30sec",//7
									"50sec",//8
									"1min",	//9
									"3min",	//A
									"5min",	//B
									"10min",//C
									"30min",//D
									"50min",//E
									"None"};//F(default)
	SendDlgItemMessage( hwnd, IDC_DISCONNECTTIME, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<16;i++){
		SendDlgItemMessage( hwnd, IDC_DISCONNECTTIME, CB_ADDSTRING, 0, (LPARAM)Disconnecttime[i] );
	}
    SendDlgItemMessage( hwnd, IDC_DISCONNECTTIME, CB_SETCURSEL, la5ppdefault.DisconnectTime, 0 );


	const char *PeriodicallyTransmissionTime[5]={"None",	//0(default)
												"10sec",	//1
												"30sec",	//2
												"60sec",	//3
												"180sec"};	//4
	SendDlgItemMessage( hwnd, IDC_PERIODICALLYTRANSMISSIONTIME, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<5;i++){
		SendDlgItemMessage( hwnd, IDC_PERIODICALLYTRANSMISSIONTIME, CB_ADDSTRING, 0, (LPARAM)PeriodicallyTransmissionTime[i] );
	}
    SendDlgItemMessage( hwnd, IDC_PERIODICALLYTRANSMISSIONTIME, CB_SETCURSEL, la5ppdefault.PeriodicallyTransmissionTime, 0 );


	const char *DIdetecttime[21]={	"Reserve0",//0	(It is not used for reservation.)
									"Reserve1",	//1	(It is not used for reservation.)
									"Reserve2",	//2	(It is not used for reservation.)
									"Reserve3",	//3	(It is not used for reservation.)
									"4ms",	//4
									"5ms",	//5
									"6ms",	//6
									"7ms",	//7
									"8ms",	//8
									"9ms",	//9
									"10ms",	//A(default)
									"11ms",	//B
									"12ms",	//C
									"13ms",	//D
									"14ms",	//E
									"15ms",	//F
									"16ms",	//10
									"17ms",	//11
									"18ms",	//12
									"19ms",	//13
									"20ms"};//14	
	SendDlgItemMessage( hwnd, IDC_DIDETECTTIME, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<21;i++){
		SendDlgItemMessage( hwnd, IDC_DIDETECTTIME, CB_ADDSTRING, 0, (LPARAM)DIdetecttime[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DIDETECTTIME, CB_SETCURSEL, la5ppdefault.DetectionTime, 0 );


	const char *DImailalert[2]={"OFF","ON"};
	CheckDlgButton(hwnd,IDC_CHECKDI1,la5ppdefault.DI[0].DIenable);
	SendDlgItemMessage( hwnd, IDC_DI1EMAILALERT, CB_RESETCONTENT, 0, 0 );
    for(i=0;i<2;i++){
		SendDlgItemMessage( hwnd, IDC_DI1EMAILALERT, CB_ADDSTRING, 0, (LPARAM)DImailalert[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DI1EMAILALERT, CB_SETCURSEL, la5ppdefault.DI[0].Logic, 0 );


	CheckDlgButton(hwnd,IDC_CHECKDI2,la5ppdefault.DI[1].DIenable);
	SendDlgItemMessage( hwnd, IDC_DI2EMAILALERT, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<2;i++){
		SendDlgItemMessage( hwnd, IDC_DI2EMAILALERT, CB_ADDSTRING, 0, (LPARAM)DImailalert[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DI2EMAILALERT, CB_SETCURSEL, la5ppdefault.DI[1].Logic, 0 );


	CheckDlgButton(hwnd,IDC_CHECKDI3,la5ppdefault.DI[2].DIenable);
	SendDlgItemMessage( hwnd, IDC_DI3EMAILALERT, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<2;i++){
		SendDlgItemMessage( hwnd, IDC_DI3EMAILALERT, CB_ADDSTRING, 0, (LPARAM)DImailalert[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DI3EMAILALERT, CB_SETCURSEL, la5ppdefault.DI[2].Logic, 0 );


	CheckDlgButton(hwnd,IDC_CHECKDI4,la5ppdefault.DI[3].DIenable);
	SendDlgItemMessage( hwnd, IDC_DI4EMAILALERT, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<2;i++){
		SendDlgItemMessage( hwnd, IDC_DI4EMAILALERT, CB_ADDSTRING, 0, (LPARAM)DImailalert[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DI4EMAILALERT, CB_SETCURSEL, la5ppdefault.DI[3].Logic, 0 );


	CheckDlgButton(hwnd,IDC_CHECKDI5,la5ppdefault.DI[4].DIenable);
	SendDlgItemMessage( hwnd, IDC_DI5EMAILALERT, CB_RESETCONTENT, 0, 0 );
	for(i=0;i<2;i++){
		SendDlgItemMessage( hwnd, IDC_DI5EMAILALERT, CB_ADDSTRING, 0, (LPARAM)DImailalert[i] );
    }
    SendDlgItemMessage( hwnd, IDC_DI5EMAILALERT, CB_SETCURSEL, la5ppdefault.DI[4].Logic, 0 );

    EnableOnlineControls( hwnd, FALSE );
    EnableOfflineControls( hwnd, TRUE );
    return FALSE;
}



/*--------------------------------------------------------------------------*/
/* Dialog box (main window) procedure                                       */
/*--------------------------------------------------------------------------*/
BOOL CALLBACK DlgProcMain( HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
    switch( uMsg )
    {
    case WM_COMMAND:
	    switch( LOWORD( wParam ) )
	    {
	    case IDC_CONNECTBYIPADDRESS:            /* first "Connect" button was clicked   */
	        ConnectLanioByIpAddress( hwnd );
	        return TRUE;
	    case IDC_DISCONNECT:                    /* "Disconnect" button was clicked  */
	        DisconnectLanio( hwnd );
	        return TRUE;
	    case IDC_WRITEDISCONNECTTIME:			/* Disconnect Time "Write" button was clicked   */
	        WriteDisconnectTime( hwnd );
	        return TRUE;
	    case IDC_READDISCONNECTTIME:            /* Disconnect Time "Read" button was clicked    */
	        ReadDisconnectTime( hwnd );
	        return TRUE;
		case IDC_WRITEPERIODICALLYTRANSMISSIONTIME: /* Periodically Transmission Time "Write" button was clicked   */
			WritePeriodicallyTransmissionTime( hwnd );
			return TRUE;
		case IDC_READPERIODICALLYTRANSMISSIONTIME:	/* Periodically Transmission Time "Read" button was clicked   */
			ReadPeriodicallyTransmissionTime( hwnd );
			return TRUE;
		case IDC_WRITEDIDETECTTIME:				/* DI Detection Time "Write" button was clicked   */
			WriteDIDetectionTime( hwnd );
			return TRUE;
		case IDC_READDIDETECTTIME:				/* DI Detection Time "Read" button was clicked    */
			ReadDIDetectionTime( hwnd );
			return TRUE;
		case IDC_WRITEDIEMAILALERT:				/* DI e-mail alert setup "Write" button was clicked   */
			WriteDIeMailAlert( hwnd );
			return TRUE;
		case IDC_READDIEMAILALERT:				/* DI e-mail alert setup "Read" button was clicked    */
			ReadDIeMailAlert( hwnd );
			return TRUE;
	    }
		break;

    case WM_INITDIALOG:
        return WmInitDialogMain( hwnd );

    case WM_CLOSE:
		if(IsWindowEnabled(GetDlgItem( hwnd, IDC_DISCONNECT ))==TRUE){
			LELanioClose( g_hLanio );			/* #### Disconnect          */
		}
	    EndDialog( hwnd, 0 );					/* Close main window		*/
	    return TRUE;
    }
    return FALSE;
}



/*--------------------------------------------------------------------------*/
/* Application program entry                                                */
/*--------------------------------------------------------------------------*/
int CALLBACK WinMain( HINSTANCE hInstance, HINSTANCE, LPSTR, int )
{
    int result;

    g_hInstance = hInstance;

    LELanioInit();                  /* #### Initialize LANIO Library        */

    result = DialogBox( hInstance, MAKEINTRESOURCE( IDD_MAIN ), NULL, DlgProcMain );

	
    LELanioEnd();                   /* #### Uninitialize LANIO Library      */

    return result;
}
